<?php
//url:http://msdn.microsoft.com/en-us/library/ff512437

class AccessTokenAuthentication {
     /*
     * Obtenir le Token d'acces
     *
     * @param string $grantType    Grant type.
     * @param string $scopeUrl     Application Scope URL.
     * @param string $clientID     Application client ID.
     * @param string $clientSecret Application client cle.
     * @param string $authUrl      Oauth Url.
     *
     * @return string.
     */
    function getTokens($grantType, $scopeUrl, $clientID, $clientSecret, $authUrl){
        try {
            $ch = curl_init();                  //Initialiser la session CURL
            $paramArr = array (                 // creer le vecteur de parametres d'entree
             'grant_type'    => $grantType,
             'scope'         => $scopeUrl,
             'client_id'     => $clientID,
             'client_secret' => $clientSecret);
             
            $paramArr = http_build_query($paramArr);  //creer une requete Http
            
            curl_setopt($ch, CURLOPT_URL, $authUrl);  //definit l'URL Curl
            curl_setopt($ch, CURLOPT_POST, TRUE);     //TRUE pour que PHP fasse un HTTP POST
            curl_setopt($ch, CURLOPT_POSTFIELDS, $paramArr);  //toutes les donnes  passer lors d'une opration de HTTP POST.
            curl_setopt ($ch, CURLOPT_RETURNTRANSFER, TRUE);  //TRUE pour retourner directement le transfert sous forme string
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);  //FALSE pour arreter CURL de verifier le certificat

            $strResponse = curl_exec($ch);  //Execute une session cURL

            $curlErrno = curl_errno($ch);   //Retourne une chaine contenant le dernier message d'erreur cURL
            if($curlErrno){
                $curlError = curl_error($ch);
                throw new Exception($curlError);
            }

            curl_close($ch);    //Ferme une session CURL

            $objResponse = json_decode($strResponse); //Recupere une chaine encodee en JSON et la convertit en une variable PHP.
                
            if(isset($objResponse->error) &&$objResponse->error)
            {
                throw new Exception($objResponse->error_description);
            }
            return $objResponse->access_token;
        } catch (Exception $e) {
            echo "Exception-".$e->getMessage();
        }
    }
}

/*
 * Class:AccessTokenAuthentication
 *
 * Create SOAP Object.
 */
class SOAPMicrosoftTranslator {
    public $objSoap;  //objet SoapClient
    
    //fonction de constructeur
    public function __construct($accessToken, $wsdlUrl){
        try {
            //l'entete de l'authentification
            $authHeader = "Authorization: Bearer ". $accessToken;
            $contextArr = array(
                'http'   => array(
                    'header' => $authHeader
            )
            );
            
            //construire le vecteur des parametres  
            $objContext = stream_context_create($contextArr);
            $optionsArr = array (
                'soap_version'   => 'SOAP_1_2',
                'encoding'          => 'UTF-8',
                'exceptions'      => true,
                'trace'          => true,
                'cache_wsdl'     => 'WSDL_CACHE_NONE',
                'stream_context' => $objContext,
                'user_agent'     => 'PHP-SOAP/'.PHP_VERSION."\r\n".$authHeader    
            );
            
            //creer l'objet SoapClient
            $this->objSoap = new SoapClient($wsdlUrl, $optionsArr);
        } catch(Exception $e){
            echo "<h2>Exception Error!</h2>";
            echo $e->getMessage();
        }
    }
}

function Translate($msg_in,&$msg_out)
{
	try {
	    
	    $wsdlUrl       = "http://api.microsofttranslator.com/V2/Soap.svc";  //l'URL de SOAP WSDL
	    $clientID       = "essai";   // id client
	    $clientSecret = "k6fJCYZExKEnN1Y36AoNqhbRtBpNdqM+WYEIn3FN9hM="; //cle
		    

	    $authUrl      = "https://datamarket.accesscontrol.windows.net/v2/OAuth2-13/"; //l'URL d'authentification
	    $scopeUrl     = "http://api.microsofttranslator.com";
	    $grantType    = "client_credentials";
		
        $authObj      = new AccessTokenAuthentication(); //creer un objet de la classe AccessTokenAuthentication

        //obtenir un token
	    $accessToken  = $authObj->getTokens($grantType, $scopeUrl, $clientID, $clientSecret, $authUrl);

		//creer un objet de la classe SOAPMicrosoftTranslator
	    $soapTranslator = new SOAPMicrosoftTranslator($accessToken, $wsdlUrl);
	        
	    //parametres :
	    $fromLanguage = "en";
	    $toLanguage   = "fr";		    
	    //le texte a traduire
	    $inputStr = $msg_in;
		    
	    //creer le vector
		$requestArg = array (
	         'text'        => $inputStr,
	         'from'        => $fromLanguage,
	         'to'            => $toLanguage,
	         'contentType' => 'text/plain',
	         'category'    => 'general');
		
       //lancer la traduction
	   $responseObj = $soapTranslator->objSoap->Translate($requestArg);
	   //recuperer le resultat
	   $msg_out = $responseObj->TranslateResult;
		   
	} catch (Exception $e) {
	    echo "Exception: " . $e->getMessage() . "<br/>";
	}
}

$msg_in="";
$msg_out="";

if(isset($_POST["msg"]) && !empty($_POST["msg"]))
{
	 $msg_in=$_POST["msg"];
     Translate($msg_in,$msg_out);
}
   
echo "
<html>
<head>
</head>
<body>
	<form method='post' action=''>
		  Saisir le texte en anglais, puis cliquer sur le bouton <b>traduire</b> : <br>
		  
		  <textarea name='msg' rows='4' cols='40'>".$msg_in."</textarea> <br><br>
		  
	    <input type='submit' value ='traduire' > <br><br>
		  
		  <textarea rows='4' cols='40' readonly style='background:#eeeeee'>".$msg_out."</textarea> 
		  
	</form>
</body>
</html>";

?>
